<?php
/**
 * {FORM_CLASS_NAME}ե९饹
 *
 * @access    public
 * @package   {PROJECT_NAME}
 * @author    {author}
 * @version   $Id: Form.php,v 1.3 2007/10/15 13:56:43 seasonstream Exp $
 */
class {FORM_CLASS_NAME} extends SyL_AdmActionForm
{
/**
 * ơ֥륯饹
 * 
 * @access protected
 * @var array
 */
var $table_classes = {FORM_TABLES};
/**
 * ơ֥륯饹δϢ
 * 
 * @access protected
 * @var array
 */
var $table_relations = array();
/**
 * ᥤƥʥ󥹥ơ֥̾
 * 
 * @access protected
 * @var string
 */
var $maintenance_table = '{FORM_MAINTENANCE_TABLE}';
/**
 * ϢURL
 * 
 * @access protected
 * @var array
 */
var $related_links = array();
/**
 * 
 * 
 * @access protected
 * @var array
 */
var $structs_config = array(
  'title'               => '{FORM_TITLE}',
  'default_sort'        => {FORM_SORTS},
  'default_search_view' => false,
  'page_records'        => 20,
  'link_range'          => 9,
  'key_name'            => 'key',
  'view_confirm'        => true,
  'view_fin'            => true,
  'view_alert'          => false,
  'enable_lst'          => true,
  'enable_new'          => true,
  'enable_upd'          => true,
  'enable_del'          => true,
  'enable_vew'          => true,
  'enable_sch'          => true
);
/**
 * ե
 * 
 * @access protected
 * @var array
 */
var $elements_config = {FORM_ELEMENTS};

}

?>
